package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````H"(``#0````PP0```````#0`(``,
M`"@`&P`:``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````P!$`
M`,`1```$`````!````$`````(````"`````@``!<,0``7#$```4`````$```
M`0````!@````8````&```+1.``"T3@``!``````0```!````U+T``-2]``#4
MO0``1`(``%@"```&`````!````(```#<O0``W+T``-R]```(`0``"`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&1PH```<*```'"@```<`0``
M'`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DU+T``-2]``#4O0``+`(``"P"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`,2ZJ^BK%C$]I95C2[1/VE]A_]`;!```
M`!@````%````1TY5``$``<`$`````0````(``<`$`````0````0````0````
M`0```$=.50``````!`````0`````````*P```$0````(````"``````0$`0E
M0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(1```````````````10``````
M````````1@````````!'````2`````````!)`````````$L`````````````
M`$P```!-`````````$\```!0````4@````````!3````5````%4`````````
M`````````````````````%8```!7````6````%D```!:``````````````!<
M`````````%T``````````````(D'<--K&IY0H^#[29E/PYOC1\8!9J_,9D-%
MU>R[XY)\LP&+;UCH[>QOQ=\?%8PES"[%F[9K"4/6(?_D#ONA;&##Y3\L#3J7
M"\_>1RW9<5@<?ZF<F^&G`@I"^M>':W^:?#-BV^W49-1\K4OCP```````````
M``````````#)`0`````````````2````8@$`````````````$@```,,!````
M`````````!(```"8`@`````````````2````_P$`````````````$@```'\"
M`````````````!(```#H`0`````````````2````V@$`````````````$@``
M`#L"`````````````!(````!```````````````@````6@$`````````````
M$@```'`!`````````````!(```!V```````````````2````R@(`````````
M````$@```.\!`````````````!(````N`0`````````````2````C`$`````
M````````$@```+<!`````````````!(````0```````````````@````L`(`
M````````````$@```)T"`````````````!(```"B```````````````2````
M+```````````````(````)L``````````````!(```";`0`````````````2
M````J0``````````````$@```*("`````````````!(```#F````````````
M```6````^0``````````````$@```$X"`````````````!(````4`0``````
M```````2````NP(`````````````$@```+$``````````````!(```"4`0``
M```````````1````:0$`````````````$@```+L``````````````!(```#0
M```````````````2````CP,`````````````$@```$,!`````````````!(`
M``"\`0`````````````2````B@``````````````$0```-<`````````````
M`!(```"*`@`````````````2````>`(`````````````$@```"`"````````
M`````!(```#B`@`````````````2````X```````````````$@```'X!````
M`````````!(```":```````````````2````)0$`````````````$@```%(!
M`````````````!(````+`@`````````````2````;`(`````````````$@``
M`,(``````````````!(```"(```````````````1````/`$`````````````
M$@```)(``````````````!(```!?`@`````````````1````TP(`````````
M````$0````D!`````````````!(````L`@`````````````2````=P$`````
M````````$@```%4``````````````!(```"O`0`````````````2````A0$`
M````````````$@```&<``````````````"(```"J`0`````````````2````
M$00``!3````$````$0`7`',#``#@3@``$`(``!(`#@`C!```,#L``/P#```2
M``X`&P0``*`_``!%````$@`.`!D#``!P.0``-@```!(`#@!G`P``L#D``'0!
M```2``X`ZP,``!C`````````$``7`-D#```LP````````!``&`!#`P``,#\`
M`&$````2``X`)@,```!@```$````$0`0`)@#``#P2P``R0```!(`#@#0`P``
MP$P``%`````2``X`"`,``#`W```0````$@`.`*0#````P````````!``%P`$
M!```0#<``"<"```2``X`\@,``+!!``#%````$@`.`+P#```@-@``-````!(`
M#@"F`P```,`````````@`!<`W@,``(!"``!*!P``$@`.`,0#```8P```````
M`!``&`!]`P``@$$``"T````2``X`40,``&`V``#-````$@`.`+$#```030``
MQP$``!(`#@!B````0"```%8"```2``X`J@,``*`B```L````$@`.`"T#``#0
M20``'@(``!(`#@!&````!&````0````1`!```%]?9VUO;E]S=&%R=%]?`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N
M951A8FQE`%])3U]S=&1I;E]U<V5D`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA
M7V9I;F%L:7IE`%]?<F5G:7-T97)?871F;W)K`%]?96YV:7)O;@!S=')N8VUP
M`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P
M<FEN=&9?8VAK`'5N;&EN:P!C;&]S961I<@!R;61I<@!03%]C=7)R96YT7V-O
M;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F
M;&%G<P!R96%D;&EN:P!097)L7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E
M='!V;@!M96UM;W9E`')E86QL;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R
M9'5P`'-T<G1O:P!S=')C;7``<W1R<F-H<@!S=&1E<G(`7U]V9G!R:6YT9E]C
M:&L`97AI=`!L<V5E:S8T`')E860`9V5T=6ED`&UK9&ER`%]?97)R;F]?;&]C
M871I;VX`7U]F<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`%!E
M<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L
M;V-K`%!,7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S
M90!P97)L7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?
M86QL;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`4$Q?;65M;W)Y7W=R87``
M7U]S=&%C:U]C:&M?9F%I;`!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?9G!?:'<`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A
M<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET
M`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T
M80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,2XS`$=,24)#7S(N,S0`1TQ)
M0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#
M7S(N,RXT`$=,24)#7S(N,0!'3$E"0U\R+C``+W5S<B]L:6(O<&5R;#4O-2XS
M."]C;W)E7W!E<FPO0T]210`````"``(``@`!``$``0`#``0``0`!``(``@`%
M``$``0`!``(``@`!``$``@`"``$`!@`$``(``0`!``$``0`!``$`!P`"``(`
M`@`"``(``0`"``(``@`!``(``0`(``(``@`&``(``@`!``$`!``"``(``@`!
M``$``0`!``(`"0`#``(`"@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`"0#^`@``$`````````!S
M'VD)```*`#`$```0````M)&6!@``"0`\!```$````!1I:0T```@`1P0``!``
M```2:6D-```'`%$$```0````LY&6!@``!@!;!```$````'(9:0D```4`9@0`
M`!````!T&6D)```$`'($```0````$6EI#0```P!^!```$````!!I:0T```(`
MB`0```````#4O0``"````-B]```(````)+\```@```#\OP``"`````3````(
M````%,````@```#TO@``!@$``/B^```&`@``_+X```8#````OP``!@0```2_
M```&!0``"+\```8&```,OP``!@<``!"_```&"```%+\```8)```8OP``!@H`
M`!R_```&"P``(+\```8,```HOP``!@T``"R_```&#@``,+\```8/```TOP``
M!A```#B_```&$0``/+\```82``!`OP``!A,``$2_```&%```2+\```85``!,
MOP``!A8``%"_```&%P``5+\```88``!8OP``!AD``%R_```&&@``8+\```8;
M``!DOP``#AP``&B_```&'0``;+\```8>``!POP``!A\``'2_```&(```>+\`
M``8A``!\OP``!B(``("_```&(P``A+\```8D``"(OP``!B4``(R_```&)@``
MD+\```8G``"4OP``!B@``)B_```&*0``G+\```8J``"@OP``!BL``*2_```&
M+```J+\```8M``"LOP``!BX``+"_```&+P``M+\```8P``"XOP``!C$``+R_
M```&,@``P+\```8S``#$OP``!C0``,B_```&-0``S+\```8V``#0OP``!C@`
M`-2_```&.0``V+\```8Z``#<OP``!CL``."_```&/```Y+\```8]``#HOP``
M!CX``.R_```&0```\+\```9!``#TOP``!D(``/B_```&0P``\+X```<_````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z,<"``"!P]N>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z'D"``"!
MPXV>``!1@^PLBT$$B474BT$(B4709:$4````B47D,<"-1=!0C4744%'_DP`!
M``"+@S````"#Q`Q04/^SB````&?H8C```(N#]````(/$$(`X``^$)0$``(N#
M@````&6+`("(H@(```.+!XUP`X/`!(EUS#W___\_#X>%`0``@^P,P>`"4/^3
MY````(MUU(L_B<&)@T0!``"+!H/$$(D!C8,'H___B4$$C8,P`0``BP")00B-
M@PJC__^)00R#_P$/CE\!``")3<B-1@2-41"--+Z-M"8`````BPB#P`2#P@2)
M2OPYQG7QBTW(@\<#@^P,C8.\<___QP2Y`````&H`4?]US%#_LSP!``#_DR0`
M``"#Q""%P`^$F````(/L#/^S/`$``(U]X/^3O````(GZB<:-@\.A___H'`X`
M`(/$$(7`#X2#````@^P,_[,\`0``_Y,<````@\00_Y-\````BT7D92L%%```
M``^%R@```(UE\(GP65M>7UV-8?S#_Y-@````B8,\`0``A<`/A)T```"#[`Q0
M_Y.0````BX.`````98L0@\00QH)R!0```.FK_O__@^P,_[,\`0``_Y-(````
M@\00Z5'___^+@T`!``"%P'02@^P,4&?HNBD``(/$$.EA____B?J-@WBA___H
M90T``(F#0`$``(7`#X1&____Z]&+1>1E*P44````=2I04(V#<Z'___^S^```
M`%#_D^````"_!````.F__O__@^P,:@'_DQ0!``#HFBX``&:09I!FD&:09I`Q
M[5Z)X8/D\%!44N@8````@<,TG```:@!J`%%6_[,8`0``Z&G]___TBQPDPV:0
M9I"+'"3#9I!FD&:09I!FD&:0Z.````"!PO^;``"-BC0!``"-@C0!```YR'0=
MBX)<````A<!T$U6)Y8/L%%'_T(/$$,G#+HUT)@##C;0F`````.B@````@<*_
MFP``58GE4XV*-`$``(V"-`$``(/L!"G(B</!Z!_!^P(!V-'X=!2+DFP```"%
MTG0*@^P(4%'_TH/$$(M=_,G#+HVT)@````"058GE4^A7____@<-KFP``@^P$
M@+LT`0```'4HBX,0`0``A<!T$H/L#/^S(`$``/^3$`$``(/$$.@T____QH,T
M`0```8M=_,G#+HVT)@````#I6____XL4),-FD&:09I"055=64XG#@>Q\`0``
MB40D$(U,)"QEH10```")A"1L`0``,<`NC70F`(M4@QP/RHD4@8/``8/X$'7O
MBTPD,(MT)&"-5"0TBVPD9(M$)&B)3"0(C8PD-`$``(M<)"R)3"0,ZPJ-M@``
M``")3"0(BPJ)QXM"&(/"!#'(,?")[HG],=B+7"0(T<")0C0Y5"0,==F+?"00
MBT0D+(LWBU<0BV\(BU\,B50D'(V4`IEY@EJ)\(M/!,'`!8GWB5PD"`'"B>B)
M3"04,=B)?"0,(<C!R0*);"08,=B+7"0P`<*)Z#'((?"+="0(,>B-M!Z9>8):
MBUPD-`'&B=#!P`6-G!V9>8):BVPD.`'&B?C!R`*)QXG(,?@AT,'*`C'(C8PI
MF7F"6HML)#P!PXGPP<`%`<.)^#'0(?#!S@(Q^(V\+YEY@EJ+;"1``<B)V<'!
M!0'(B=$Q\2'9,=&-E"J9>8):BVPD1`'YB<?!QP7!RP(!^8GW,=\AQ\'(`C'W
MC;0NF7F"6HML)$@!^HG/P<<%`?J)QXG8,?@AR#'8C9PKF7F"6HML)$P!\(G6
MP<8%`?")SHGYP<X",?$AT3'YC;POF7F"6HML)%`!V8G#P<,%`=F)TXGRP<L"
M,=HAPL'(`C'RC;0NF7F"6HML)%0!^HG/P<<%`?J)QXG8,?@AR#'8C9PKF7F"
M6HML)%@!\(G6P<8%`?")SHGYP<X",?$AT3'YC;POF7F"6HML)%P!V8G#P<,%
M`=F)TXGRP<L",=HAPL'(`C'RC;0NF7F"6HML)&`!^HG/P<<%`?J)QXG8,?@A
MR#'8C9PKF7F"6HML)&0!\(G6P<8%`?")SHGYP<X",?$AT3'YC;POF7F"6@'9
MB</!PP4!V8G3B?+!RP(QVB'"P<@",?*)Q8G8`?J)SS'HP<<%(<C!R0(!^HM\
M)&@QV(VT/IEY@EJ+?"1L`?")UL'&!8V\.YEY@EH!\(GN,<Z)PR'6P<,%,>[!
MR@(!]XMT)'`!WXG+,=.-M#69>8):BVPD="'#P<@",<N-C"F9>8):BVPD>`'>
MB?O!PP4!WHG3,<,A^S'3P<\"C90JF7F"6@'+B?'!P04!RXG!,?DA\<'.`C'!
M`=&)VL'"!0'1BU0D?(V$$*'KV6Z)^C'R,=K!RP(!PHG(P<`%`<*+A"2`````
MC;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/BXPDA````(VT#J'KV6Z)V3'Y
M,=$!\8G&P<8%`?&)UHN4)(@```#!S@*-G!.AZ]ENB?HQ\C'"`=J)R\'(`L'#
M!0':B<.+A"2,````C;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/BXPDD```
M`(VT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4))0```#!S@*-G!.AZ]ENB?HQ
M\C'"P<@"`=J)R\'#!0':B<.+A"28````C;P'H>O9;HGP,=@QR,')`@'XB=?!
MQP4!^(G/BXPDG````(VT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4)*````#!
MS@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"2D````C;P'H>O9;HGP
M,=@QR,')`@'XB=?!QP4!^(G/BXPDJ````(VT#J'KV6Z)V3'Y,=$!\8G&P<8%
M`?&)UHN4)*P```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"2P
M````C;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/BXPDM````(VT#J'KV6Z)
MV3'Y,=$!\8G&P<8%`?&)UHN4)+@```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)
MR\'#!0':B<.+A"2\````C;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/BXPD
MP````(VT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4),0```#!S@*-G!.AZ]EN
MB?HQ\C'"P<@"B<4!VHN$),@```")R\'#!0':C9P'H>O9;HGP,>@QR`'8B=/!
MR0+!PP4!V(GK"<N)WXGK(=<AR\'*`@G[B[PDS````(VT/MR\&X\!\XG&P<8%
M`?.)S@G6B?>)SB''(=;!R`()_HN\)-````"-O#W<O!N/`?>)WL'&!0'WB=8)
MQHGUB=8AW2'&P<L"">Z+K"34````C8PIW+P;CXG=B<,!SHGY">O!P04A^P'.
MB<$AZ0G9BYPDV````(V<&MR\&X^)\@'+P<\"B>G!P@4)^0'3B>HA\<'.`B'Z
M"<J+C"3<````C8P(W+P;CXG8`='!P`4!P8GX"?")PHGX(=HA\,'+`@G0BY0D
MX````(V4%=R\&X\!PHG(P<`%`<*)\`G8B<6)\"'-(=C!R0()Z(NL).0```"-
MO"_<O!N/B=T!^(G7"<W!QP4AU0'XB<^)V2'Y">F+K"3H````C;0NW+P;CXG]
M`?&)QL'&!0'QB=:)^L'.`@GU(?(AQ<'(`@GJBZPD[````(V<*]R\&X\!VHG+
MP<,%`=J)PXGP"=B)Q8GP(<TAV,')`@GHBZPD\````(V\+]R\&X^)W0'XB=<)
MS<''!2'5`?B)SXG9(?D)Z8NL)/0```"-M"[<O!N/B?T!\8G&P<8%`?&)UHGZ
MP<X""?4A\B'%">J+K"3X````C9PKW+P;CP':B<O!R`+!PP4!VHG#B?`)V(G%
MB?`AS2'8P<D"">B+K"3\````C;POW+P;CXG=`?B)UPG-P<<%(=4!^(G/B=DA
M^0GIBZPD``$``(VT+MR\&X^)_0'QB<;!Q@4!\8G6B?K!S@()]2'R(<7!R`()
MZHNL)`0!``"-G"O<O!N/B<4!VHG+P<,%`=J)\PG#B?`ARR'H"=B+G"0(`0``
MC9P?W+P;CP'8B=/!R0+!PP4!V(GK"<N)WXGK(=<AR\'*`@G[B[PD#`$``(VT
M/MR\&X\!\XG&P<8%`?.)S@G6B?>)SB''(=;!R`()_HN\)!`!``"-O#W<O!N/
MB=4!_HG?"<7!QP4AW<'+`@'^B=<AQPGOBZPD%`$``(V,*=R\&X^)Q0'YB?<)
MW<''!2'U`?F)QR'?">^+K"08`0``C90JW+P;CXML)`P!UXG*P<X"P<(%`=>+
ME"0<`0``C900UL%BRHG8,?`QR,')`@'0B?K!P@4!T(N4)"`!``"-G!/6P6+*
MB?(QRC'ZP<\"`=J)P\'#!0':BYPD)`$``(VT'M;!8LJ)RS'[,<,!\XG6P<8%
M`?.)QHN$)"@!``#!S@*-C`'6P6+*B?@Q\#'0P<H"`<B)V<'!!0'(B=&+E"0L
M`0``C907UL%BRHGW,<\QWP'7B<+!P@4!UXN4)#`!``#!RP*-M!;6P6+*B<HQ
MVC'"`?*)_L'&!0'RB<:+A"0T`0``P<X"C80!UL%BRHG9,?$Q^<'/`@'!B=#!
MP`4!P8N$)#@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"0\`0``P<L"
MC906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*B=HQRC'"
MP<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%BRHG+,?LQ\\'.`@'#B=#!P`4!
MPXN$)$@!``"-C`'6P6+*B?@Q\#'0P<H"`<B)V<'!!0'(B=&+E"1,`0``C907
MUL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!``"-M!;6P6+*B<HQVC'"`?*)
M_L'&!0'RB<:+A"14`0``P<X"C80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!P8N$
M)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"1<`0``P<L"C906UL%B
MRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-O!?6P6+*B=HQRC'"P<@"`?J)
M]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!S@(!^XG7P<<%`?N+O"1H`0``
MC;P]UL%BR@'/B<$Q\3'1P<H"`?F)W\''!0'YBWPD$(D/BTPD%`'9B4\$BVPD
M&(M,)`@!ZHE7"(T4,8E7#(M4)!P!T(E'$(N$)&P!``!E*P44````=0N!Q'P!
M``!;7E]=P^B!(0``D%7H0B$``('%+H\``%=64X/L'(E4)`B%P`^$L@```(G!
MBX6T````BQ"%T@^$H`````^V`83`=`0\/755,?^+&H7;=#V)5"0,B=B)TXE,
M)`2)QHVT)@````"#[`17_W0D#%;_E?````"#Q!"%P'4&@#P^/70TBW,$@\,$
MA?9UVHGS@\0<B=A;7E]=PXVV`````(G/#[9'`8/'`83`=`0\/77Q*<_KF(UV
M`(M4)`R)\(G>B<.+1"0(*=:-7#L!P?X"B3"#Q!R)V%M>7UW#+HUT)@"#Q!PQ
MVXG86UY?7<.-="8`5NA:(```@<9.C@``4XG#@^Q\9:$4````B40D=#'`C40D
M%%!3_Y;4````@\00A<!U-XM4)!R!X@#P``"!^@!```!T"('Z`*```'4?@^P(
M:@)3_Y9H````@\00A<`/E,`/ML#K!HUT)@`QP(M4)&QE*Q44````=0:#Q'1;
M7L/H'B```"Z-M"8`````C;8`````55=6Z,@?``"!QKR-``!3B<.![(P```!E
MH10```")1"1\,<"%VW0%@#L`=22+1"1\92L%%`````^%/`$``('$C````%M>
M7UW#+HVT)@````"#[`Q3_Y9X````B<>#Q!"%P'3)@^P,5_^6E````(/$$(7`
M#X2X````@'@3+HU0$W4/@'H!`'3<+HVT)@````"0@'@3+@^$M@```(E4)`R#
M[`Q3_Y:@````BU0D'(G%B10DB50D'/^6H````(U$!0*)!"3_EL````")Q5B-
MAB2A__]:BU0D%%)34&K_:@%5_Y;H````@\08C40D)%!5_Y9P````@\00@_C_
M=!"+1"0L)0#P```]`$```'1E@^P,5?^6I````(/$$(/L#%7_EF0```"#Q!#I
M.?___XVV`````(/L#%?_EK@```")'"3_ELP```"#Q!#IX?[__RZ-="8`@'H!
M+@^%0/___X!Z`@`/A/_^___I,?___XVT)@````")Z.B)_O__ZY_HDAX``&:0
M5E/H*?#__X'#/8P``(/L!(V#@.'__XNS@````%"-@RJA____LX0```!09?\V
M_Y/\````6(V#Y*+__UIJ`%!0C8-&H?___[-`````4&7_-O^3C````(/$)%M>
MPRZ-="8`55=64X'L`!```(,,)`"#[##HWAT``(''SHL``(E4)!")QF6A%```
M`(F$)"`0```QP&C_#P``C8=;H?__C6PD)%50_Y?8````@\00A<!^$(G#C4#_
M@'P<&P!U187`=3F+AX````"#[`3_="005F7_,/^74````(/$$(N$)!P0``!E
M*P44````=4*!Q"P0``!;7E]=PXUT)@")PXVV`````(/L!%-J+U7_E^P```"#
MQ!"%P'2KBX>`````4U569?\P_Y>L````@\00ZZ[H8!T``%7H(AT``('%#HL`
M`%>)QU93B=.#[#AEH10```")1"0H,<`QP(`Z/0^4P`'#4_^5H````(/$$(E$
M)`2)^(U4)!CHF_O__X7`#X03`0``@^P,B<90_Y6@````BTPD%(/$$#G(#X/8
M````BT0D&,'@`HE$)`B+A;0```")!"0/M@>$P`^$J0$``#P]#X2A`0``B?B-
MM"8`````#[90`8/``832=`6`^CUU\"GXBPPDBW0D"(/L#(M4)!`#,8U$$`)0
M_Y7`````B0:#Q!"%P'11BPPDBW0D"(L!C4\!BQ0P#[8'B`(\/70=A,!U"NL7
MC70F`#P]=`\/M@&#P@&#P0&(`H3`=>W&`CTQP"Z-M"8`````#[8,`XA,`@&#
MP`&$R77QBT0D'&4K!10````/A1,!``"#Q"Q;7E]=PRZ-M"8`````,<"-M@``
M```/MA0#B!0&@\`!A-)U\NO'+HVT)@````"+A;0```"+$(D$)(LRA?8/A,(`
M```Q]BZ-M"8`````D(GP@\8!BPRRA<EU](T$A0P```"+C3@!``"%R75CB50D
M#(/L#%#'A3@!```!````_Y7`````B<&#Q!"%P`^$7?___XT$M0````"#[`2)
M1"0,4(M4)!1248E,)!S_E=P```"+1"00BTPD'(/$$(D(QT2Q!`````")="08
MZ7W^__^0@^P(4%+_E3@```")P8M$)!"#Q!")"(7)#X0!____C02U`````(E$
M)`CKPRZ-="8`,<#I<_[__[@(````,?;I4/___^@8&P``+HVT)@````#H!!L`
M``6_B```@^P,C9"`X?__4HV0*J'___^PA````%*+D(````!E_S+_D/P```"#
MQ!S#+HVT)@````"-="8`55=64X'L`!```(,,)`"![``0``"##"0`@^P<,>WH
M3NS__X'#8H@``&6A%````(F$)`P@```QP/^3%````(/L"(V39J'__U)0C8-J
MH?__4&@!$```:@&-M"0G$```5O^3Z````(/$'&@`$```C7PD$E=6_Y/8````
M@\00A<!X+(/L#(G&C4`!4/^3P````(G%@\00A<!T%(/L!%974/^3G````,9$
M-0``@\00BX0D#"```&4K!10```!U#8'$'"```(GH6UY?7</H`QH``(UV`.CT
M&0``!:^'``#I(?___Y!55U93@>P`$```@PPD`('LG````.AWZ___@<.+AP``
MB[PDL!```(NL)+00``!EH10```")A"2,$```,<"-1"0LB40D%(G"C8-XH?__
MZ!_X__^#[`AJ+XG&5_^3/````(/$$(7`=#*-@X&A__^)^N@=_/__B?B+E"2,
M$```92L5%`````^%F0$``('$G!```%M>7UW#C70F`(/L#%7_DP0!``!:68V+
MCJ'__XE,)!114/^3T````(V+D*'__XG%C8.9HO__@\00B40D&(7M=)>`?0``
MB4PD'`^$Z@```(UV`(7V=!:#[`A55O^3#`$``(/$$(7`#X2G````@^P,5?^3
MH````(G"C40%_X/$$#G%<A'K(RZ-="8`Q@``@^@!.<5T!8`X+W3Q@^P,5?^3
MH````(G"@\00B50D$(/L#%?_DZ````"+5"0@C40"`8/$$#W_#P``#X<,____
M@^P$5_]T)"15_W0D*&@`$```:@&-K"2H````5?^3Z````(/$&/]T)!Q5_Y-P
M````@\00A<!U$(M$)#PE`/```#T`@```=$^#[`C_="04:@#_D]````")Q8/$
M$(7`#X2I_O__@'T```^%&?___X7V=`6`/BYT$+H!````C:MVH?__Z5;___^`
M?@$`=+OKZ"Z-M"8`````@^P(:@%5_Y-H````@\00A<!UGHGJC8.!H?__Z(#Z
M__^#[`Q5_Y,$`0``@\00Z5/^___HR1<``"Z-M"8`````D%;H>A<``('&;H4`
M`%.#[`R+7"08:B]3_Y94````A<"-4`&)\`]%VHE<)""#Q!1;7O^@!`$``"Z-
MM"8`````9I!55U93@>P`$```@PPD`(/L'.@R%P``@<4>A0``B[0D,!```&6A
M%````(F$)`P0```QP(7V#X2F````@#X`#X2=````@^P,5O^5H````(U(`8/$
M$('Y`!````^'X0```(U<)`R#^00/@Z0```"%R0^%W````(U$`_\YPW(.ZQ%F
MD,8``(/H`3G8=`6`."]T\8/L"&HO4_^55````(/$$(7`=#XYPP^"A@```(/L
M#%/_E00!``"#Q!"+E"0,$```92L5%`````^%I````('$'!```%M>7UW#+HVT
M)@````!FD(N$)`P0``!E*P44````=7^-A7:A__^)A"0P$```@<0<$```B>A;
M7E]=_Z`$`0``D(M4#OR)WXE4#`B)P<'I`O.EZ4[___\NC;0F`````&:0Q@``
MZ7+___\NC;0F`````#'`Z7#___\NC;0F`````)`/MA:(5"0,]L$"#X04____
M#[=4#OYFB50,"ND%____Z`P6```NC;0F`````(UT)@!55U;HN!4``('&K(,`
M`%.#["QEH10```")1"0<,<"-7"08BZZT````C;Z2H?__B=J)^.A)]/__A<!T
M+HM4)!B+10"-!)"+4`2)$(72=.!FD(M0"(/`!(D0A=)U](G:B?CH&_3__X7`
M==*+KK0```"-OINA__^)VHGXZ`+T__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)T
MX(UV`(M0"(/`!(D0A=)U](G:B?CHT_/__X7`==&+KK0```"-OJ.A__^)VHGX
MZ+KS__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:
MB?CHB_/__X7`==&+KK0```"-OJRA__^)VHGXZ'+S__^%P'0OBU0D&(M%`(T$
MD(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:B?CH0_/__X7`==&-AK.A__^+
MOK0```")!"2+!"2)VN@F\___A<!T+(M4)!B+!XT$D(M0!(D0A=)TX(M0"(/`
M!(D0A=)U](L$)(G:Z/KR__^%P'74BZZT````C;[#H?__B=J)^.CA\O__A<!T
M-HM4)!B+10"-!)"+4`2)$(72=.`NC;0F`````&:0BU`(@\`$B1"%TG7TB=J)
M^.BK\O__A<!URHV&>*'__XN^M````(E$)`2+1"0$B=KHC/+__X7`=#.+5"08
MBP>-!)"+4`2)$(72=-^-M@````"+4`B#P`2)$(72=?2+1"0$B=KH6?+__X7`
M=<V-AL^A__^+OK0```")1"0,BT0D#(G:Z#KR__^%P'0QBU0D&(L'C020BU`$
MB1"%TG3?C70F`(M0"(/`!(D0A=)U](M$)`R)VN@)\O__A<!USXV&V:'__XN^
MM````(E$)`B+1"0(B=KHZO'__X7`=#&+5"08BP>-!)"+4`2)$(72=-^-="8`
MBU`(@\`$B1"%TG7TBT0D"(G:Z+GQ__^%P'7/BZZT````C;[CH?__B=J)^.B@
M\?__A<!T-8M4)!B+10"-!)"+4`2)$(72=.`NC;0F`````)"+4`B#P`2)$(72
M=?2)VHGXZ&OQ__^%P'7+BZZT````C;Z!H?__B=J)^.A2\?__A<!T+XM4)!B+
M10"-!)"+4`2)$(72=."-=@"+4`B#P`2)$(72=?2)VHGXZ"/Q__^%P'71B=J-
MANVA___H$O'__X7`=`N)PHM$)`CH(_7__XG:C8;^H?__Z/;P__^%P'0-B<*-
MAA"B___H!?7__XG:C88;HO__Z-CP__^)PH7`="N+1"0$Z.GT__^+1"0<92L%
M%````'4SBP0D@\0LC98\HO__6UY?7>G']/__B=J-ABNB___HFO#__X7`=,V)
MPHM$)`SHJ_3__^O`Z`02``"-="8`Z/01```%KW\``(/L'&6+%10```")5"0,
M,=*-5"0(C8#/H?__Z%?P__^%P'0K#[80@/HP#Y3`A-(/E,()T(/P`0^VP(M4
M)`QE*Q44````=0R#Q!S#C70F`#'`Z^?HGQ$``"Z-M"8`````C;0F`````%/H
M*N/__X'#/G\``(/L&&6A%````(E$)`PQP(U$)"2)1"0(4(N#F````/]T)"1J
M`?\P_Y-T````QP0D_P```/^3%`$``"Z-M"8`````C78`55=64XV<)```__^!
M[``0``"##"0`.=QU\H/L+.B_XO__@</3?@``B40D!(G'9:$4````B80D'``!
M`#'`:@)J`&H`5_^3"`$``(/`_X/2_XE$)!B+="08B=>)5"0<P?\?,?@I^#'2
M)?__```Q^C'X*?@9^HM\)!PIQAG7@\00C6PD%(7_#XBR````C;8`````:@!7
M5O]T)!#_DP@!```AT(/$$(/X_P^$O````(/L!&@(``$`5?]T)!#_DU@```"#
MQ!"#^/\/A'T```"#^`=V4(U$!?@YZ')(C14D`0``ZP>#Z`$YZ'(YBPP:.0AU
M\HN+*`$``#E(!'7G*>B9`?`1^HN,)!P``0!E*PT4````=7B!Q"P``0!;7E]=
MPRZ-="8`@<8``/__@]?_B?")^C4``/__]]()T`^%5/___[C_____NO_____K
MN(N$)!P``0!E*P44````=3"#[`R-@TNB__]09^A(_O__BX0D'``!`&4K!10`
M``!U$(/L#(V#/J+__U!GZ"C^___HLP\``(UV`%/H2N'__X'#7GT``(/L"/^3
ML````(/L#%#_DZ@```"#Q!"%P'0"BP"#Q`A;PXUV`%7H0@\``('%+GT``%=6
M4X/L+&6A%````(E$)!PQP(VU5Z+__XU4)!B+?"1`B?#HS>W__X7`=`>`.`")
MPW4BBT0D'&4K!10```!U=8GZ@\0LB?!;7E]=Z<7Q__\NC70F`(/L#%?_E:``
M``")1"0<B1PD_Y6@````BU0D'(U$`@*)!"3_E<````"#Q`R)PHV%CJ'__U-0
MC869HO__5U!J_VH!4HE4)"S_E>@```"#Q""+5"0,BT0D'&4K!10```!TC>B[
M#@``+HVT)@````"-=@!55U93Z$?@__^!PUM\``"![/P```"+A"00`0``C7PD
M*(GZB40D#&6A%````(F$).P````QP(V#;J+__\>$)*0`````````B80DG```
M`(V#=J'__XF$)*````"-@PFB__^)A"2L````C8-SHO__B80DL````(V#)J+_
M_XF$)+0```"-@WNB__^)A"2X````C8-_HO__B80DD````(V#A*+__XF$))0`
M``"-@WBA___'A"2\`````````,>$))@`````````B40D&.AC[/__A<!T"X`X
M`(G&#X6,!```_Y.P````@^P,4/^3J````(/$$(7`#X39`P``BRB%[0^$SP,`
M`(/L#%7_DZ````"-1``!@\00@^P,4/^3P````(G&#[9%`(/$$(ET)`B$P'0[
MC8N-HO__B7PD!(GWB<XNC70F`(/L#`^VP(/%`5!6:O]J`5>#QP+_D^@````/
MMD4`@\0@A,!UW(M\)`2-M"2H````C8,0HO__ZQ,NC;0F`````)"+1@2#Q@2%
MP'0VB?KHG^O__XG%A<!TZ8`X`'3DZ&_L__^%P'3;@^P,5?^3!`$``(G%@\00
MA<!U."Z-M"8`````C;0DG````(LNA>UT(X!]```/A/$"``")Z.@R[/__A<`/
MA?(```"+;@2#Q@2%[77=@^P,5?^3H````%K_="04B<;_DZ````"-M`8$!```
MB30D_Y/`````B40D%(G!C8.2HO___W0D&%"-@Y"A__^)1"0@4(V#EZ+__U6)
MS5!J_VH!4?^3Z````(/$*&C``0``5?^3&````(/$$(/X_W41_Y,0````BP"#
M^!$/A=@"``"#[`A7_W0D$/^3U````(G%@\00A<!T>8/L#/]T)!"+1"0<_S"-
M@TRC__]0,?:+@Y@```!J`?\P_Y,L````@\0@BX0D[````&4K!10````/A6$$
M``"!Q/P```")\%M>7UW#C;0F`````(/L#(/&!%7_DP0!``")Q8/$$(7`#X35
M_O__Z?G^__\NC;0F`````)"+1"0X)0#P```]`$````^%<____XM$)$")1"00
M_Y.P````.40D$`^%6____XM$)#@E_P$``#W``0``#X5'____@^P,5O^3P```
M`(GZB<:-@V*B___HU^G__X/$$(7`#X1$`@``@^P(4(M$)!C_,&?H3/'__XE$
M)""#Q!"%P`^$)0(``(/L#/]T)!S_DZ````")PH/$$(/X`W9&@^P(C8.@HO__
M4(M$)!R-1!#\B50D*%#_DPP!``"#Q!"%P'4BBU0D'(/Z!`^$`0,``(M$)!"`
M?!#[+P^$\@(``(VV`````(GZC;O/H?__B?CH0>G__X7`#X3)`0``#[8`A,`/
MA+X!```\,`^$M@$``(V3/*+__XGXC;ODHO__Z#/M____DQ0```!74(V#Q*+_
M__]T)!#_="004&K_:@%6_Y/H````C8/2HO__@\0@B40D#.LV9I#_DQ````"#
M.!%U0/^3%````(/%`8/L#%=54/]T)"#_="0@_W0D+&K_:@%6_Y/H````@\0P
M@^P(:,`!``!6_Y,8````@\00@_C_=+6#[`S_="00_Y-D````BT0D*(GRZ)WL
M__^)-"1GZ'3Z__^#Q!#I[/W__XUT)@`Q[>DA_?__D(N$))````"-M"20````
MA<!T((VV`````(GZZ$'H__^%P'0%@#@`=3B+1@2#Q@2%P'7F@^P,C:MGHO__
M:@W_D\````")QH/$$(E$)`BX4P```.D'_/__+HVT)@````!FD(/L#%#_DP0!
M``")Q8/$$(7`=+7IN?O__X/L"%#_="00BT0D'/\PC8,0H___Z3G]__^-M"8`
M````@^P,4&?HOOG__X/$$(N$).P```!E*P44````#X6<`0``B;0D$`$``('$
M_````(G86UY?7?^@!`$``(VV`````(M$)`R+`(E$)!#IS/W__RZ-M"8`````
MD(/L"&H`_W0D'/^3*````(/$$(7`#X0P_O__B40D#.B-]___B40D$(E4)!2%
MT@^(%_[__X/`]FH`@]+_4E"+3"0848E,)!S_DP@!``"#Q`QJ!HV$))(```!0
MBTPD&%&)3"0<_Y-8````@\00BTPD#(/X!@^%\@```(&\)(H`````0T%##X7!
M_?__9H&\)(X```!(10^%L?W__VH`BT0D%(M4)!B#P,Z#TO]24%&)3"0<_Y,(
M`0``@\0,:BB-O"3+````5XM,)!A1_Y-8````@\00@_@H#X60````C8/DHO__
MQH0DZP````!0C8.UHO__5_]T)!#_="004&K_:@%6_Y/H````@\0@Z<_]__^+
M1"0,BU`$A=(/A`7]__^#[`Q2B50D'/^3H````(/$$(/X`P^&Z_S__X/L"(V+
MI:+__U&+5"08C40"_%#_DPP!``"+5"0<@\00A<`/150D$(E4)!#IN_S__^B&
M!P``BX0D[````&4K!10```!UZX/L#(V#JJ+__U!GZ-;U__^-M@````!55U93
MZ/?8__^!PPMU``"#[!QEH10```")1"0,,<"-?"0(B?J+LX````!EBRX/MD5D
MB$5EC8.SH?__Z*'E__^%P'0)@#@Q#X1D`0``9^@.\?__98LNC8/CHO__:@-J
M`5!5_Y-,````B<6#Q!"%P'0J@^P$C8/EHO__4(M%#/\P9?\V_Y-0````BT4,
MBP"#Q!#V0`I`#X5&`0``C8/JHO__:@-J`5!E_S;_DTP```")Q8/$$(7`="J)
M^HV#@:'__^@<Y?__A<`/A/0```"#[`10BT4,_S!E_S;_DU````"#Q!"#[`2-
M@^RB__]J`5!E_S;_DR````"-DP&C__^#Q`Q24&7_-O^34````&6+!HGZQD!E
M`(V#>*'__^C"Y/__@\00B8-``0``B<:%P'1#@^P(:,`!``!6_Y,8````C5`!
M@\00@_H!=@F#^!$/A:4```"+1"0,92L%%`````^%N````(/$'%M>7UW#C;0F
M`````(/L#/^S1`$``&?H,??__XF#0`$``(G&@\00A<!UGXM$)`QE*P44````
M=7Z#[`R-@Z"C__]0_Y/@````+HUT)@"`>`$`#X2;_O__Z8W^__^0BX-$`0``
MBQ"+10R+`.A>Y___Z0K___\NC;0F`````)"#[`A09?\V_Y/$````@\00Z:7^
M__^+5"0,92L5%````'474(N#1`$``%;_,(V#Q*/__U#_D^````#H0@4``&:0
M5U93Z-C6__^!P^QR``"#[!!EH10```")1"0,,<"-5"0(BW0D((V#SZ'__^B0
MX___A<!T&P^V$(#Z,`^4P(32#Y3""-!U"87V=`6`/@!U&8M$)`QE*P44````
M=6B#Q!!;7E_#+HUT)@"#[`Q69^A.[?__B<=86FHO5_^35````(7`C5`!#T7Z
MB3PD_Y,$`0``@\0,C9.2HO__:@124/^3\````(/$$(7`=:6+1"0,92L%%```
M`'4-@\00B?!;7E_I;.3__^AW!```C;0F`````.AD!```!1]R``"#[!AJ8/^0
MP````,<``2-%9\=`!(FKS>_'0`C^W+J8QT`,=E0R$,=`$/#ATL/'0!0`````
MQT`8`````,=`7`````"#Q!S#55=6Z-@#``"!QLQQ``!3@^P<BUPD,(M$)#B+
M?"0TP>`#`T,4BTL8C6L<B4,4BT0D.(/1`,'H'0'(B4,8BT-<A<`/A3$!``"#
M?"0X/P^.;@$``(M$)#B#Z$")1"0,P>@&C7`!B40D",'F!@'^C70F`(L'@\=`
MB44`BT?$B44$BT?(B44(BT?,B44,BT?0B440BT?4B444BT?8B448BT?<B44<
MBT?@B44@BT?DB44DBT?HB44HBT?LB44LBT?PB44PBT?TB44TBT?XB44XBT?\
MB44\B=CHY]7__SGW=9.+1"0(BU0D#,'@!BG"B50D.(-\)#@$<E.+!HGIB4,<
MBT0D.(M4)#B+1`;\B405_(U#((/@_"G!*<X#3"0X@^'\@_D$<A*#X?PQTHLL
M%HDL$(/"!#G*<O.+1"0XB4-<@\0<6UY?7<,NC70F`(M$)#B%P'3D#[8&B$,<
M]D0D.`)TUXM$)#B+3"0X#[=$!OYFB40-_NO#C;0F`````+I`````*<([5"0X
M#T]4)#B#[`0!Z%*)5"005U#_EIP```"+5"08BT-<`="#Q!")0UR#^$!UC8G8
M*50D.`'7Z`75___IA_[__XG^Z2?___\NC;0F`````)#H1`(```7_;P``55=6
M4X/L'(M<)#2+="0PB40D!(M3%(MK&(U['(G0P>H##\V#XC\/R(E$)`B-0@'&
M1!,<@(/X.`^."0$``+I`````C0P'*<)T(S'`]L(!=`RX`0```,8!`#G0<Q#&
M!`$`QD0!`0"#P`(YT'+PB=CH<]3__XU7!,=#'``````QP(/B_,='-``````I
MUXU/.(G7P>D"\ZN+1"0(B6M4B4-8B=CH0-3__XL#P>@8B`:+`\'H$(A&`8L#
MB&8"BP.(1@,/MD,'B$8$#[=#!HA&!8M#!(AF!HM#!(A&!P^V0PN(1@@/MT,*
MB$8)BT,(B&8*BT,(B$8+#[9##XA&#`^W0PZ(1@V+0PR(9@Z+0PR(1@\/MD,3
MB$80#[=#$HA&$8M#$(AF$HM#$(A&$XM$)`2)7"0P@\0<6UY?7?^@9````"Z-
MM"8`````9I"Z.````"G"`?B#^@0/@HX```"-2`3'``````"#X?S'1!#\````
M`"G(`="#X/R#^`0/@AG___^)Q[H$````@^?\B7PD#(UX_\'O`L<!`````(/G
M`3G"#X/T_O__A?]T&,=!!`````"+1"0,N@@````YP@^#V/[__XM$)`S'!!$`
M````QT01!`````"#P@@YPG+JZ;G^__\NC;0F`````&:0A=(/A*?^___&``#V
MP@(/A)O^__\QR6:)3!#^Z8_^__^+-"3#BSPDPXLL),-FD&:0Z"0````%WVT`
M`(/L#/^P(`$``/]T)!S_="0<_W0D'/^01````(/$',.+!"3#9I"05E[H\O__
M_P6M;0``@^P,_Y#(````````4X/L".A_T?__@<.3;0``@\0(6\,`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S
M:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V
M,P`M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!&P,[&`$``"(```"P
M?___8`$``-!___^\#```,(+__S0!``!@@___A`$``$"/___(`0``()#__T`"
M``"PD/__C`(``#"2__]``P``D)+__Y`#``!@D___(`0``+"5__^@!```\)7_
M_\0$``#`EO__7`4``-"6__]P!0```)G__W`&``!`F?__H`8``,":__\D!P``
MP)[__V0'```PG___@`<``("?__^H!P``$*'__U@(``!`H?__A`@``!"B___D
M"```8*G__X`+``"`J___4`P``%"L__\$#0``H*S__R`-``!PKO__<`T``("P
M__^P#0``A+#__\0-``"(L/__V`T``)"P___L#0``N;#__Q`.``#`L/__)`X`
M`!0``````````7I2``%\"`$;#`0$B`$'"!`````<````](#__RP`````````
M%``````````!>E(``7P(`1L,!`2(`0``(````!P```!(?O__(``````."$8.
M#$H/"W0$>``_&CLJ,B0B0````$````#4@?__WPL```!!#@B%`D$.#(<#00X0
MA@1!#A2#!4@.D`,#R0L*#A1!PPX00<8.#$''#@A!Q0X$00L```!T````A```
M`'"-___<`````$$."(4"3`X,AP-!#A"&!$$.%(,%0PXP`DD.-$$..$0./$$.
M0$D.,%D*#A1#PPX00<8.#$''#@A!Q0X$1PMT"@X40\,.$$'&#@Q!QPX(0<4.
M!$8+0PX41<,.$$'&#@Q!QPX(0<4.!`!(````_````-B-__^"`````$$."(8"
M3`X,@P-%#H@!40Z,`4$.D`%)#H`!80Z(`4(.C`%!#I`!20Z``6`*#@Q!PPX(
M0<8.!$$+````L````$@!```<CO__?@$```!!#@B%`D$.#(<#00X0A@1,#A2#
M!4@.H`%L"@X40<,.$$'&#@Q!QPX(0<4.!$D+0PZL`4$.L`%+#J`!1PZL`4$.
ML`%)#J`!<0ZL`4$.L`%I#JP!1PZH`44.K`%!#K`!00ZT`4(.N`%"#KP!00[`
M`4D.J`%%#JP!00ZP`4D.H`%8#JP!00ZP`4D.H`%##JP!00ZP`4D.H`%.#JP!
M00ZP`5(.H`$`3````/P!``#HCO__6P````!!#@B&`D$.#(,#3@X030X43`X8
M00X<0PX@1PX<1PX80@X<00X@00XD3`XH00XL0PXP20X,0<,."$'&#@0```",
M````3`(``/B.___0`````$$."(4"00X,AP-!#A"&!$$.%(,%1@Z4($<.Q"!E
M#L@@2P[,($$.T"!)#L`@70[$($0.R"!!#LP@0P[0($D.P"!6"@X40<,.$$'&
M#@Q!QPX(0<4.!$4+2P[$($$.R"!"#LP@00[0($D.P"!+#L0@00[(($$.S"!#
M#M`@20[`(`!\````W`(``#B/__](`@```$$."(4"3`X,AP-##A"&!$$.%(,%
M10Y,5PY020Y`6@Y,0PY030Y``E0.3$L.4$L.0`)I"@X40<,.$$'&#@Q!QPX(
M0<4.!$D+`F0.3$$.4%4.0%(.1$4.2$4.3$$.4%4.0%<.2$$.3$$.4$\.0```
M`"````!<`P``")'__S0`````30X01PX43`X800X<20X@20X$`)0```"``P``
M))'__\T`````00X(A0)!#@R'`T$.$(8$00X4@P5&#I0@2@Z40$<.L$!E#KA`
M1PZ\0$$.P$!'#L1`10[(0$(.S$!(#M!`20ZT0$4.N$!%#KQ`00[`0$D.L$!'
M#KQ`1@[`0$L.L$!'#K1`00ZX0$$.O$!!#L!`3@ZP0%8*#A1#PPX00<8.#$''
M#@A!Q0X$00L`$````!@$``!<D?__$`````````#\````+`0``%B1__\G`@``
M`$$."(4"00X,AP-!#A"&!$$.%(,%1@Z4($H.L"$"0`ZX(4(.O"%##L`A20ZP
M(6T*#A1!PPX00<8.#$''#@A!Q0X$10M##KPA00[`(4<.O"%!#K@A2PZ\(4$.
MP"%7#K`A8`ZX(4$.O"%!#L`A20ZP(4L.O"%!#L`A3PZP(5T.O"%!#L`A2PZP
M(4<.O"%!#L`A40ZP(4X.M"%!#K@A1`Z\(4$.P"%$#L0A10[((4(.S"%(#M`A
M20ZX(40.O"%!#L`A20ZP(5<.N"%$#KPA0@[`(4L.L"%^#K@A0@Z\(4$.P"%)
M#K`A5`Z\(4$.P"%)#K`A+````"P%``"(DO__-@````!!#@B&`DP.#(,#0PX8
M1@X<00X@5PX,0<,."$'&#@0`@````%P%``"8DO__=`$```!!#@B%`D$.#(<#
M00X0A@1!#A2#!48.E"!'#K`@=0Z\($$.P"!,#K`@?PZX($(.O"!!#L`@20ZP
M($\.O"!!#L`@20ZP(%H*#A1!PPX00<8.#$''#@A!Q0X$2PMC"@X40\,.$$'&
M#@Q!QPX(0<4.!$<+````/````.`%``"4D____`,```!!#@B%`D$.#(<#00X0
MA@1,#A2#!4,.0`.X`PH.%$?##A!!Q@X,0<<."$'%#@1%"Q@````@!@``5)?_
M_V$`````30X@`D8*#@1%"P`D````/`8``*B7__]%`````$$."(,"3@X@50XD
M2@XH0@XL0@XP````K````&0&``#0E___C0$```!!#@B%`D$.#(<#00X0A@1!
M#A2#!4<,`Y2`!$X-!$,.P(`$8@[$@`1"#LB`!$(.S(`$00[0@`1[#L"`!%0.
MQ(`$00[(@`1!#LR`!$0.T(`$2P[`@`1,#L2`!$4.R(`$00[,@`1$#M"`!$D.
MP(`$`E0*#A1!PPX00<8.#$''#@A!Q0X$1@M["@[,@`1'#M"`!$8+4PH.S(`$
M1P[0@`1&"P`H````%`<``+"8__\M`````$$."(,"3@X020X<00X@20X020X(
M0<,.!````%P```!`!P``M)C__\4`````00X(A0),#@R'`T$.$(8$00X4@P5#
M#D!^"@X40\,.$$'&#@Q!QPX(0<4.!$H+0PY,00Y09PY$20Y(00Y,1PY000Y4
M0@Y80@Y<00Y@30Y``)@"``"@!P``))G__TH'````00X(A0)!#@R'`T$.$(8$
M00X4@P51#I`"`M`.G`)!#J`"20Z0`E4.G`)!#J`"30Z0`D,.G`)!#J`"3PZ0
M`EX.G`)'#J`"00ZD`D(.J`)"#JP"00ZP`E`.D`("2`Z<`D$.H`)+#I`"?PZ<
M`D$.H`)'#IP"1`Z@`F@.I`)!#J@"2PZL`D<.L`)##K0"0@ZX`D(.O`)!#L`"
M20Z8`D4.G`)!#J`"20Z0`ED.F`)!#IP"1`Z@`DL.D`)'#IP"1`Z@`D8.I`)'
M#J@"2@ZL`D(.L`))#I`"6@H.%$/##A!!Q@X,0<<."$'%#@1("T,.G`)$#J`"
M2PZ0`@)9#IP"00Z@`E@.D`)+#I@"00Z<`D8.H`)-#I`"2PZ<`D0.H`)+#I`"
M2`Z8`D<.G`)-#J`"20Z0`@)J#I0"00Z8`DH.G`)$#J`"00ZD`D(.J`)"#JP"
M00ZP`D\.D`)?#IP"00Z@`D$.I`)!#J@"1`ZL`D0.L`)$#K0"0@ZX`D(.O`)!
M#L`"20Z0`D,.F`)%#IP"00Z@`DD.D`)(#IP"1`Z@`ET.D`("1@Z<`D@.H`)+
M#I`"6PZ<`D$.H`)+#I`"3`H.F`)!#IP"1`Z@`D8.I`)2"T,.G`)!#J`"20Z0
M`F$*#A1#PPX00<8.#$''#@A!Q0X$3`M;#I@"0@Z<`D0.H`))#I`"9@Z4`D0.
MF`)!#IP"10Z@`DT.E`)"#I@"2`Z<`D4.H`)-#I`"<`Z4`D\.F`)!#IP"00Z@
M`DT.E`)"#I@"2`Z<`D4.H`))#I`"6`Z4`D<.F`)$#IP"1`Z@`D$.I`)"#J@"
M0@ZL`D$.L`))#I`"5PZ<`D$.H`)-#I`"3`Z8`D<.G`))#J`"30Z0`F@.G`)'
M#J`"````S````#P*``#8G?__'@(```!!#@B%`D$.#(<#00X0A@1!#A2#!4X.
M,`)+#C1"#CA!#CQ!#D!+#C!'#C1'#CA%#CQ##D!.#C!2#C1"#CA!#CQ##D!+
M#C!<#C1!#CA%#CQ##D!)#C!##C1(#CA!#CQ##D!/#C1!#CA!#CQ##D!=#C!/
M#CA%#CQ!#D!,#C!B"@X40<,.$$'&#@Q!QPX(0<4.!$@+0PH./$8.0%$.,%0.
M/$<.0$L+<PXX00X\0PY`20XP4PH.-$<..$(./$<.0$8+`&@````,"P``*)__
M_\D`````00X(AP)!#@R&`T$.$(,$3@X@`DX*#A!!PPX,0<8."$''#@1&"T,.
M+$$.,$D.+$$.*$(.+$$.,%H.)$@.*$$.+$$.,$D.(%0*#A!#PPX,0<8."$''
M#@1%"P```$0```!X"P``#'/__U8"````1`P!`$D0!0)U`$$0!P)U?$00!@)U
M>!`#`G5T3`\#=7`&`V\!"L$,`0!!PT'&0<=!Q4,,!`1!"Q@```#`"P``1)__
M_U``````30X<0@X@`D`.!`!,````W`L``'B?___'`0```$$."(4"00X,AP-!
M#A"&!$P.%(,%0PXP`RP!"@X40<,.$$'&#@Q!QPX(0<4.!$8+`D,.-$,..$4.
M/$$.0%(.,#P````L#```^*#__Q`"````2PX(A0)!#@R'`T$.$(8$00X4@P5#
M#C`#*P$*#A1!PPX00<8.#$''#@A!Q0X$4`L0````;`P``,BB__\$````````
M`!````"`#```N*+__P0`````````$````)0,``"HHO__!``````````@````
MJ`P``)RB__\I`````$T.$$8.%$0.&$0.'$0.($D.!``0````S`P``*&B__\$
M`````````!@```#@#```E*+__Q4`````00X(00X$30X0````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#`(P``
M<",```$```#S`@```0```/X"```=````D@0```P`````(```#0```$A1```9
M````U+T``!L````$````&@```-B]```<````!````/7^_V\T`@``!0```&P)
M```&````?`,```H```"U!```"P```!`````5``````````,```#DO@```@``
M``@````4````$0```!<```"X$0``$0```(`/```2````.`(``!,````(````
M'@````@```#[__]O`0``"/[__V_@#@``____;P$```#P__]O(@X``/K__V\&
M`````````````````````````````````````````````````````````-R]
M`````````````#8@````````````````````````````````````````````
M``````````````````````#020``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!`(`````````3````*4$%2+G!M"@````#L8@``1T-#.B`H1TY5
M*2`Q,RXR+C$@,C`R,S`X,#$``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M```````````````````````````````````````````````````````+````
M`0````(```"T`0``M`$``!,```````````````$`````````$P````<````"
M````R`$``,@!```D```````````````$`````````"8````'`````@```.P!
M``#L`0``*```````````````!``````````Y````!P````(````4`@``%`(`
M`"````````````````0`````````1P```/;__V\"````-`(``#0"``!(`0``
M!@`````````$````!````%$````+`````@```'P#``!\`P``\`4```<````!
M````!````!````!9`````P````(```!L"0``;`D``+4$``````````````$`
M````````80```/___V\"````(@X``"(.``"^````!@`````````"`````@``
M`&X```#^__]O`@```.`.``#@#@``H`````<````!````!`````````!]````
M"0````(```"`#P``@`\``#@"```&``````````0````(````A@````D```!"
M````N!$``+@1```(````!@```!8````$````"````(\````!````!@`````@
M````(```(```````````````!`````````"*`````0````8````@(```("``
M`"```````````````!`````$````E0````$````&````0"```$`@```%,0``
M```````````0`````````)L````!````!@```$A1``!(40``%```````````
M````!`````````"A`````0````(`````8````&```&Y```````````````0`
M````````J0````$````"````<*```'"@```<`0`````````````$````````
M`+<````!`````@```(RA``",H0``*`T`````````````!`````````#!````
M#@````,```#4O0``U+T```0```````````````0````$````S0````\````#
M````V+T``-B]```$```````````````$````!````-D````&`````P```-R]
M``#<O0``"`$```<`````````!`````@```#B`````0````,```#DO@``Y+X`
M`!P!``````````````0````$````YP````$````#`````,````#````8````
M```````````$`````````.T````(`````P```!C````8P```%```````````
M````!`````````#R`````0```#``````````&,```!L```````````````$`
M```!`````0````,``````````````#/```#[```````````````!````````
!````
